fnss.netconfig.weights.set_weights_delays — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.weights.set_weights_delays

`set_weights_delays`(topology)

  Assign link weights to links proportionally their delay. Weights are normalized so that the minimum weight is 1.

  Parameters : | topology : Topology The topology on which weights are applied.

  Examples

      >>> import fnss
      >>> topology = fnss.erdos_renyi_topology(50, 0.1)
      >>> fnss.set_delays_constant(topology, 2, 'ms')
      >>> fnss.set_weights_delays(topology)

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »